package xstream;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.annotations.Annotations;

import java.io.Serializable;
import java.lang.reflect.Field;


public class BaseRule implements Serializable {

    /**
     * Serialize the condition to XML string
     *
     * @return XML string
     */
    protected String toXML() {
        XStream xstream = new XStream();
        Annotations.configureAliases(xstream, getClass());
        Field[] fields = getClass().getDeclaredFields();
        for (Field f : fields) {
            Annotations.configureAliases(xstream, f.getType());
        }
        String xmlString = xstream.toXML(this);
        xstream = null;
        return xmlString;
    }

    /**
     * Build the rule from XML string
     *
     * @param xmlString XML string
     * @param clazz     Condition class to be de-serialized
     * @return Condition object
     */
    public static IRule fromXML(String xmlString, Class clazz) {
        XStream xstream = new XStream();
        Annotations.configureAliases(xstream, clazz);
        Field[] fields = clazz.getDeclaredFields();
        for (Field f : fields) {
            Annotations.configureAliases(xstream, f.getType());
        }
        IRule rule = (IRule) xstream.fromXML(xmlString);
        xstream = null;
        return rule;
    }


}
